### Logger

```python
if __name__ == "__main__":
    logger = Logger("logger")
    logger.debug("debug")
    logger.info("info")
    logger.warning("warning")
    logger.error("error")
```

### Author

[KhoiDD](https://github.com/mazino2d)